package com.yunfeiyun.agmp.fms.mapper;

import com.yunfeiyun.agmp.fms.domain.SysWarn;
import com.yunfeiyun.agmp.fms.domain.reqvo.SelectCountOfScreenReqVo;
import com.yunfeiyun.agmp.fms.domain.reqvo.SysWarnReqVo;
import com.yunfeiyun.agmp.fms.domain.resvo.SysWarnResVo;

import java.util.List;

/**
 * 系统预警Mapper接口
 * 
 * @author 杨晓辉
 * @date 2023-07-05
 */
public interface SysWarnMapper 
{
    /**
     * 查询系统预警
     * 
     * @param warnId 系统预警主键
     * @return 系统预警
     */
    public SysWarn selectSysWarnByWarnId(String warnId);

    /**
     * 查询系统预警列表
     * 
     * @param reqVo 系统预警
     * @return 系统预警集合
     */
    public List<SysWarnResVo> selectSysWarnList(SysWarnReqVo reqVo);
    public List<SysWarnResVo> selectSysWarnListOfScreen(SysWarnReqVo reqVo);

    /**
     * 统计数量
     * @param reqVo
     * @return
     */
    public List<SysWarnResVo> selectCountOfSysWarn(SysWarnReqVo reqVo);

    /**
     * 查询系统预警数量
     * @param reqVo
     * @return
     */
    public Integer selectCount(SelectCountOfScreenReqVo reqVo);

    /**
     * 新增系统预警
     * 
     * @param sysWarn 系统预警
     * @return 结果
     */
    public int insertSysWarn(SysWarn sysWarn);

    /**
     * 修改系统预警
     * 
     * @param sysWarn 系统预警
     * @return 结果
     */
    public int updateSysWarn(SysWarn sysWarn);

    /**
     * 删除系统预警
     * 
     * @param warnId 系统预警主键
     * @return 结果
     */
    public int deleteSysWarnByWarnId(String warnId);

    /**
     * 批量删除系统预警
     * 
     * @param warnIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteSysWarnByWarnIds(String[] warnIds);
}
